Class: Aws::CodeCommit::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CodeCommit::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-codecommit/client.rb,
sig/client.rbs
Overview
An API client for CodeCommit. To construct a client, you need to configure a :region and :credentials.
client = Aws::CodeCommit::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchAssociateApprovalRuleTemplateWithRepositoriesResponseSuccess, _BatchDescribeMergeConflictsResponseSuccess, _BatchDisassociateApprovalRuleTemplateFromRepositoriesResponseSuccess, _BatchGetCommitsResponseSuccess, _BatchGetRepositoriesResponseSuccess, _CreateApprovalRuleTemplateResponseSuccess, _CreateCommitResponseSuccess, _CreatePullRequestApprovalRuleResponseSuccess, _CreatePullRequestResponseSuccess, _CreateRepositoryResponseSuccess, _CreateUnreferencedMergeCommitResponseSuccess, _DeleteApprovalRuleTemplateResponseSuccess, _DeleteBranchResponseSuccess, _DeleteCommentContentResponseSuccess, _DeleteFileResponseSuccess, _DeletePullRequestApprovalRuleResponseSuccess, _DeleteRepositoryResponseSuccess, _DescribeMergeConflictsResponseSuccess, _DescribePullRequestEventsResponseSuccess, _EvaluatePullRequestApprovalRulesResponseSuccess, _GetApprovalRuleTemplateResponseSuccess, _GetBlobResponseSuccess, _GetBranchResponseSuccess, _GetCommentReactionsResponseSuccess, _GetCommentResponseSuccess, _GetCommentsForComparedCommitResponseSuccess, _GetCommentsForPullRequestResponseSuccess, _GetCommitResponseSuccess, _GetDifferencesResponseSuccess, _GetFileResponseSuccess, _GetFolderResponseSuccess, _GetMergeCommitResponseSuccess, _GetMergeConflictsResponseSuccess, _GetMergeOptionsResponseSuccess, _GetPullRequestApprovalStatesResponseSuccess, _GetPullRequestOverrideStateResponseSuccess, _GetPullRequestResponseSuccess, _GetRepositoryResponseSuccess, _GetRepositoryTriggersResponseSuccess, _ListApprovalRuleTemplatesResponseSuccess, _ListAssociatedApprovalRuleTemplatesForRepositoryResponseSuccess, _ListBranchesResponseSuccess, _ListFileCommitHistoryResponseSuccess, _ListPullRequestsResponseSuccess, _ListRepositoriesForApprovalRuleTemplateResponseSuccess, _ListRepositoriesResponseSuccess, _ListTagsForResourceResponseSuccess, _MergeBranchesByFastForwardResponseSuccess, _MergeBranchesBySquashResponseSuccess, _MergeBranchesByThreeWayResponseSuccess, _MergePullRequestByFastForwardResponseSuccess, _MergePullRequestBySquashResponseSuccess, _MergePullRequestByThreeWayResponseSuccess, _PostCommentForComparedCommitResponseSuccess, _PostCommentForPullRequestResponseSuccess, _PostCommentReplyResponseSuccess, _PutFileResponseSuccess, _PutRepositoryTriggersResponseSuccess, _TestRepositoryTriggersResponseSuccess, _UpdateApprovalRuleTemplateContentResponseSuccess, _UpdateApprovalRuleTemplateDescriptionResponseSuccess, _UpdateApprovalRuleTemplateNameResponseSuccess, _UpdateCommentResponseSuccess, _UpdatePullRequestApprovalRuleContentResponseSuccess, _UpdatePullRequestDescriptionResponseSuccess, _UpdatePullRequestStatusResponseSuccess, _UpdatePullRequestTitleResponseSuccess, _UpdateRepositoryEncryptionKeyResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_approval_rule_template_with_repository(params = {}) ⇒ Struct
Creates an association between an approval rule template and a specified repository.
-
#batch_associate_approval_rule_template_with_repositories(params = {}) ⇒ Types::BatchAssociateApprovalRuleTemplateWithRepositoriesOutput
Creates an association between an approval rule template and one or more specified repositories.
-
#batch_describe_merge_conflicts(params = {}) ⇒ Types::BatchDescribeMergeConflictsOutput
Returns information about one or more merge conflicts in the attempted merge of two commit specifiers using the squash or three-way merge strategy.
-
#batch_disassociate_approval_rule_template_from_repositories(params = {}) ⇒ Types::BatchDisassociateApprovalRuleTemplateFromRepositoriesOutput
Removes the association between an approval rule template and one or more specified repositories.
-
#batch_get_commits(params = {}) ⇒ Types::BatchGetCommitsOutput
Returns information about the contents of one or more commits in a repository.
-
#batch_get_repositories(params = {}) ⇒ Types::BatchGetRepositoriesOutput
Returns information about one or more repositories.
-
#create_approval_rule_template(params = {}) ⇒ Types::CreateApprovalRuleTemplateOutput
Creates a template for approval rules that can then be associated with one or more repositories in your Amazon Web Services account.
-
#create_branch(params = {}) ⇒ Struct
Creates a branch in a repository and points the branch to a commit.
-
#create_commit(params = {}) ⇒ Types::CreateCommitOutput
Creates a commit for a repository on the tip of a specified branch.
-
#create_pull_request(params = {}) ⇒ Types::CreatePullRequestOutput
Creates a pull request in the specified repository.
-
#create_pull_request_approval_rule(params = {}) ⇒ Types::CreatePullRequestApprovalRuleOutput
Creates an approval rule for a pull request.
-
#create_repository(params = {}) ⇒ Types::CreateRepositoryOutput
Creates a new, empty repository.
-
#create_unreferenced_merge_commit(params = {}) ⇒ Types::CreateUnreferencedMergeCommitOutput
Creates an unreferenced commit that represents the result of merging two branches using a specified merge strategy.
-
#delete_approval_rule_template(params = {}) ⇒ Types::DeleteApprovalRuleTemplateOutput
Deletes a specified approval rule template.
-
#delete_branch(params = {}) ⇒ Types::DeleteBranchOutput
Deletes a branch from a repository, unless that branch is the default branch for the repository.
-
#delete_comment_content(params = {}) ⇒ Types::DeleteCommentContentOutput
Deletes the content of a comment made on a change, file, or commit in a repository.
-
#delete_file(params = {}) ⇒ Types::DeleteFileOutput
Deletes a specified file from a specified branch.
-
#delete_pull_request_approval_rule(params = {}) ⇒ Types::DeletePullRequestApprovalRuleOutput
Deletes an approval rule from a specified pull request.
-
#delete_repository(params = {}) ⇒ Types::DeleteRepositoryOutput
Deletes a repository.
-
#describe_merge_conflicts(params = {}) ⇒ Types::DescribeMergeConflictsOutput
Returns information about one or more merge conflicts in the attempted merge of two commit specifiers using the squash or three-way merge strategy.
-
#describe_pull_request_events(params = {}) ⇒ Types::DescribePullRequestEventsOutput
Returns information about one or more pull request events.
-
#disassociate_approval_rule_template_from_repository(params = {}) ⇒ Struct
Removes the association between a template and a repository so that approval rules based on the template are not automatically created when pull requests are created in the specified repository.
-
#evaluate_pull_request_approval_rules(params = {}) ⇒ Types::EvaluatePullRequestApprovalRulesOutput
Evaluates whether a pull request has met all the conditions specified in its associated approval rules.
-
#get_approval_rule_template(params = {}) ⇒ Types::GetApprovalRuleTemplateOutput
Returns information about a specified approval rule template.
-
#get_blob(params = {}) ⇒ Types::GetBlobOutput
Returns the base-64 encoded content of an individual blob in a repository.
-
#get_branch(params = {}) ⇒ Types::GetBranchOutput
Returns information about a repository branch, including its name and the last commit ID.
-
#get_comment(params = {}) ⇒ Types::GetCommentOutput
Returns the content of a comment made on a change, file, or commit in a repository.
-
#get_comment_reactions(params = {}) ⇒ Types::GetCommentReactionsOutput
Returns information about reactions to a specified comment ID.
-
#get_comments_for_compared_commit(params = {}) ⇒ Types::GetCommentsForComparedCommitOutput
Returns information about comments made on the comparison between two commits.
-
#get_comments_for_pull_request(params = {}) ⇒ Types::GetCommentsForPullRequestOutput
Returns comments made on a pull request.
-
#get_commit(params = {}) ⇒ Types::GetCommitOutput
Returns information about a commit, including commit message and committer information.
-
#get_differences(params = {}) ⇒ Types::GetDifferencesOutput
Returns information about the differences in a valid commit specifier (such as a branch, tag, HEAD, commit ID, or other fully qualified reference).
-
#get_file(params = {}) ⇒ Types::GetFileOutput
Returns the base-64 encoded contents of a specified file and its metadata.
-
#get_folder(params = {}) ⇒ Types::GetFolderOutput
Returns the contents of a specified folder in a repository.
-
#get_merge_commit(params = {}) ⇒ Types::GetMergeCommitOutput
Returns information about a specified merge commit.
-
#get_merge_conflicts(params = {}) ⇒ Types::GetMergeConflictsOutput
Returns information about merge conflicts between the before and after commit IDs for a pull request in a repository.
-
#get_merge_options(params = {}) ⇒ Types::GetMergeOptionsOutput
Returns information about the merge options available for merging two specified branches.
-
#get_pull_request(params = {}) ⇒ Types::GetPullRequestOutput
Gets information about a pull request in a specified repository.
-
#get_pull_request_approval_states(params = {}) ⇒ Types::GetPullRequestApprovalStatesOutput
Gets information about the approval states for a specified pull request.
-
#get_pull_request_override_state(params = {}) ⇒ Types::GetPullRequestOverrideStateOutput
Returns information about whether approval rules have been set aside (overridden) for a pull request, and if so, the Amazon Resource Name (ARN) of the user or identity that overrode the rules and their requirements for the pull request.
-
#get_repository(params = {}) ⇒ Types::GetRepositoryOutput
Returns information about a repository.
-
#get_repository_triggers(params = {}) ⇒ Types::GetRepositoryTriggersOutput
Gets information about triggers configured for a repository.
-
#list_approval_rule_templates(params = {}) ⇒ Types::ListApprovalRuleTemplatesOutput
Lists all approval rule templates in the specified Amazon Web Services Region in your Amazon Web Services account.
-
#list_associated_approval_rule_templates_for_repository(params = {}) ⇒ Types::ListAssociatedApprovalRuleTemplatesForRepositoryOutput
Lists all approval rule templates that are associated with a specified repository.
-
#list_branches(params = {}) ⇒ Types::ListBranchesOutput
Gets information about one or more branches in a repository.
-
#list_file_commit_history(params = {}) ⇒ Types::ListFileCommitHistoryResponse
Retrieves a list of commits and changes to a specified file.
-
#list_pull_requests(params = {}) ⇒ Types::ListPullRequestsOutput
Returns a list of pull requests for a specified repository.
-
#list_repositories(params = {}) ⇒ Types::ListRepositoriesOutput
Gets information about one or more repositories.
-
#list_repositories_for_approval_rule_template(params = {}) ⇒ Types::ListRepositoriesForApprovalRuleTemplateOutput
Lists all repositories associated with the specified approval rule template.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Gets information about Amazon Web Servicestags for a specified Amazon Resource Name (ARN) in CodeCommit.
-
#merge_branches_by_fast_forward(params = {}) ⇒ Types::MergeBranchesByFastForwardOutput
Merges two branches using the fast-forward merge strategy.
-
#merge_branches_by_squash(params = {}) ⇒ Types::MergeBranchesBySquashOutput
Merges two branches using the squash merge strategy.
-
#merge_branches_by_three_way(params = {}) ⇒ Types::MergeBranchesByThreeWayOutput
Merges two specified branches using the three-way merge strategy.
-
#merge_pull_request_by_fast_forward(params = {}) ⇒ Types::MergePullRequestByFastForwardOutput
Attempts to merge the source commit of a pull request into the specified destination branch for that pull request at the specified commit using the fast-forward merge strategy.
-
#merge_pull_request_by_squash(params = {}) ⇒ Types::MergePullRequestBySquashOutput
Attempts to merge the source commit of a pull request into the specified destination branch for that pull request at the specified commit using the squash merge strategy.
-
#merge_pull_request_by_three_way(params = {}) ⇒ Types::MergePullRequestByThreeWayOutput
Attempts to merge the source commit of a pull request into the specified destination branch for that pull request at the specified commit using the three-way merge strategy.
-
#override_pull_request_approval_rules(params = {}) ⇒ Struct
Sets aside (overrides) all approval rule requirements for a specified pull request.
-
#post_comment_for_compared_commit(params = {}) ⇒ Types::PostCommentForComparedCommitOutput
Posts a comment on the comparison between two commits.
-
#post_comment_for_pull_request(params = {}) ⇒ Types::PostCommentForPullRequestOutput
Posts a comment on a pull request.
-
#post_comment_reply(params = {}) ⇒ Types::PostCommentReplyOutput
Posts a comment in reply to an existing comment on a comparison between commits or a pull request.
-
#put_comment_reaction(params = {}) ⇒ Struct
Adds or updates a reaction to a specified comment for the user whose identity is used to make the request.
-
#put_file(params = {}) ⇒ Types::PutFileOutput
Adds or updates a file in a branch in an CodeCommit repository, and generates a commit for the addition in the specified branch.
-
#put_repository_triggers(params = {}) ⇒ Types::PutRepositoryTriggersOutput
Replaces all triggers for a repository.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a resource in CodeCommit.
-
#test_repository_triggers(params = {}) ⇒ Types::TestRepositoryTriggersOutput
Tests the functionality of repository triggers by sending information to the trigger target.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags for a resource in CodeCommit.
-
#update_approval_rule_template_content(params = {}) ⇒ Types::UpdateApprovalRuleTemplateContentOutput
Updates the content of an approval rule template.
-
#update_approval_rule_template_description(params = {}) ⇒ Types::UpdateApprovalRuleTemplateDescriptionOutput
Updates the description for a specified approval rule template.
-
#update_approval_rule_template_name(params = {}) ⇒ Types::UpdateApprovalRuleTemplateNameOutput
Updates the name of a specified approval rule template.
-
#update_comment(params = {}) ⇒ Types::UpdateCommentOutput
Replaces the contents of a comment.
-
#update_default_branch(params = {}) ⇒ Struct
Sets or changes the default branch name for the specified repository.
-
#update_pull_request_approval_rule_content(params = {}) ⇒ Types::UpdatePullRequestApprovalRuleContentOutput
Updates the structure of an approval rule created specifically for a pull request.
-
#update_pull_request_approval_state(params = {}) ⇒ Struct
Updates the state of a user's approval on a pull request.
-
#update_pull_request_description(params = {}) ⇒ Types::UpdatePullRequestDescriptionOutput
Replaces the contents of the description of a pull request.
-
#update_pull_request_status(params = {}) ⇒ Types::UpdatePullRequestStatusOutput
Updates the status of a pull request.
-
#update_pull_request_title(params = {}) ⇒ Types::UpdatePullRequestTitleOutput
Replaces the title of a pull request.
-
#update_repository_description(params = {}) ⇒ Struct
Sets or changes the comment or description for a repository.
-
#update_repository_encryption_key(params = {}) ⇒ Types::UpdateRepositoryEncryptionKeyOutput
Updates the Key Management Service encryption key used to encrypt and decrypt a CodeCommit repository.
-
#update_repository_name(params = {}) ⇒ Struct
Renames a repository.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-codecommit/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5223 5224 5225 |
# File 'lib/aws-sdk-codecommit/client.rb', line 5223 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5226 5227 5228 |
# File 'lib/aws-sdk-codecommit/client.rb', line 5226 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_approval_rule_template_with_repository(params = {}) ⇒ Struct
Creates an association between an approval rule template and a specified repository. Then, the next time a pull request is created in the repository where the destination reference (if specified) matches the destination reference (branch) for the pull request, an approval rule that matches the template conditions is automatically created for that pull request. If no destination references are specified in the template, an approval rule that matches the template contents is created for all pull requests in that repository.
83 |
# File 'sig/client.rbs', line 83
def associate_approval_rule_template_with_repository: (
|
#batch_associate_approval_rule_template_with_repositories(params = {}) ⇒ Types::BatchAssociateApprovalRuleTemplateWithRepositoriesOutput
Creates an association between an approval rule template and one or more specified repositories.
95 |
# File 'sig/client.rbs', line 95
def batch_associate_approval_rule_template_with_repositories: (
|
#batch_describe_merge_conflicts(params = {}) ⇒ Types::BatchDescribeMergeConflictsOutput
Returns information about one or more merge conflicts in the attempted merge of two commit specifiers using the squash or three-way merge strategy.
111 |
# File 'sig/client.rbs', line 111
def batch_describe_merge_conflicts: (
|
#batch_disassociate_approval_rule_template_from_repositories(params = {}) ⇒ Types::BatchDisassociateApprovalRuleTemplateFromRepositoriesOutput
Removes the association between an approval rule template and one or more specified repositories.
131 |
# File 'sig/client.rbs', line 131
def batch_disassociate_approval_rule_template_from_repositories: (
|
#batch_get_commits(params = {}) ⇒ Types::BatchGetCommitsOutput
Returns information about the contents of one or more commits in a repository.
143 |
# File 'sig/client.rbs', line 143
def batch_get_commits: (
|
#batch_get_repositories(params = {}) ⇒ Types::BatchGetRepositoriesOutput
Returns information about one or more repositories.
156 |
# File 'sig/client.rbs', line 156
def batch_get_repositories: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 5208 5209 5210 5211 5212 |
# File 'lib/aws-sdk-codecommit/client.rb', line 5196 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CodeCommit') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-codecommit' context[:gem_version] = '1.102.0' Seahorse::Client::Request.new(handlers, context) end |
#create_approval_rule_template(params = {}) ⇒ Types::CreateApprovalRuleTemplateOutput
Creates a template for approval rules that can then be associated with one or more repositories in your Amazon Web Services account. When you associate a template with a repository, CodeCommit creates an approval rule that matches the conditions of the template for all pull requests that meet the conditions of the template. For more information, see AssociateApprovalRuleTemplateWithRepository.
166 |
# File 'sig/client.rbs', line 166
def create_approval_rule_template: (
|
#create_branch(params = {}) ⇒ Struct
Creates a branch in a repository and points the branch to a commit.
174 |
# File 'sig/client.rbs', line 174
def create_branch: (
|
#create_commit(params = {}) ⇒ Types::CreateCommitOutput
Creates a commit for a repository on the tip of a specified branch.
190 |
# File 'sig/client.rbs', line 190
def create_commit: (
|
#create_pull_request(params = {}) ⇒ Types::CreatePullRequestOutput
Creates a pull request in the specified repository.
228 |
# File 'sig/client.rbs', line 228
def create_pull_request: (
|
#create_pull_request_approval_rule(params = {}) ⇒ Types::CreatePullRequestApprovalRuleOutput
Creates an approval rule for a pull request.
247 |
# File 'sig/client.rbs', line 247
def create_pull_request_approval_rule: (
|
#create_repository(params = {}) ⇒ Types::CreateRepositoryOutput
Creates a new, empty repository.
259 |
# File 'sig/client.rbs', line 259
def create_repository: (
|
#create_unreferenced_merge_commit(params = {}) ⇒ Types::CreateUnreferencedMergeCommitOutput
Creates an unreferenced commit that represents the result of merging two branches using a specified merge strategy. This can help you determine the outcome of a potential merge. This API cannot be used with the fast-forward merge strategy because that strategy does not create a merge commit.
273 |
# File 'sig/client.rbs', line 273
def create_unreferenced_merge_commit: (
|
#delete_approval_rule_template(params = {}) ⇒ Types::DeleteApprovalRuleTemplateOutput
Deletes a specified approval rule template. Deleting a template does not remove approval rules on pull requests already created with the template.
293 |
# File 'sig/client.rbs', line 293
def delete_approval_rule_template: (
|
#delete_branch(params = {}) ⇒ Types::DeleteBranchOutput
Deletes a branch from a repository, unless that branch is the default branch for the repository.
303 |
# File 'sig/client.rbs', line 303
def delete_branch: (
|
#delete_comment_content(params = {}) ⇒ Types::DeleteCommentContentOutput
Deletes the content of a comment made on a change, file, or commit in a repository.
314 |
# File 'sig/client.rbs', line 314
def delete_comment_content: (
|
#delete_file(params = {}) ⇒ Types::DeleteFileOutput
Deletes a specified file from a specified branch. A commit is created on the branch that contains the revision. The file still exists in the commits earlier to the commit that contains the deletion.
327 |
# File 'sig/client.rbs', line 327
def delete_file: (
|
#delete_pull_request_approval_rule(params = {}) ⇒ Types::DeletePullRequestApprovalRuleOutput
Deletes an approval rule from a specified pull request. Approval rules can be deleted from a pull request only if the pull request is open, and if the approval rule was created specifically for a pull request and not generated from an approval rule template associated with the repository where the pull request was created. You cannot delete an approval rule from a merged or closed pull request.
344 |
# File 'sig/client.rbs', line 344
def delete_pull_request_approval_rule: (
|
#delete_repository(params = {}) ⇒ Types::DeleteRepositoryOutput
Deletes a repository. If a specified repository was already deleted, a null repository ID is returned.
Deleting a repository also deletes all associated objects and metadata. After a repository is deleted, all future push calls to the deleted repository fail.
355 |
# File 'sig/client.rbs', line 355
def delete_repository: (
|
#describe_merge_conflicts(params = {}) ⇒ Types::DescribeMergeConflictsOutput
Returns information about one or more merge conflicts in the attempted merge of two commit specifiers using the squash or three-way merge strategy. If the merge option for the attempted merge is specified as FAST_FORWARD_MERGE, an exception is thrown.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
370 |
# File 'sig/client.rbs', line 370
def describe_merge_conflicts: (
|
#describe_pull_request_events(params = {}) ⇒ Types::DescribePullRequestEventsOutput
Returns information about one or more pull request events.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
389 |
# File 'sig/client.rbs', line 389
def describe_pull_request_events: (
|
#disassociate_approval_rule_template_from_repository(params = {}) ⇒ Struct
Removes the association between a template and a repository so that approval rules based on the template are not automatically created when pull requests are created in the specified repository. This does not delete any approval rules previously created for pull requests through the template association.
399 |
# File 'sig/client.rbs', line 399
def disassociate_approval_rule_template_from_repository: (
|
#evaluate_pull_request_approval_rules(params = {}) ⇒ Types::EvaluatePullRequestApprovalRulesOutput
Evaluates whether a pull request has met all the conditions specified in its associated approval rules.
410 |
# File 'sig/client.rbs', line 410
def evaluate_pull_request_approval_rules: (
|
#get_approval_rule_template(params = {}) ⇒ Types::GetApprovalRuleTemplateOutput
Returns information about a specified approval rule template.
421 |
# File 'sig/client.rbs', line 421
def get_approval_rule_template: (
|
#get_blob(params = {}) ⇒ Types::GetBlobOutput
Returns the base-64 encoded content of an individual blob in a repository.
431 |
# File 'sig/client.rbs', line 431
def get_blob: (
|
#get_branch(params = {}) ⇒ Types::GetBranchOutput
Returns information about a repository branch, including its name and the last commit ID.
442 |
# File 'sig/client.rbs', line 442
def get_branch: (
|
#get_comment(params = {}) ⇒ Types::GetCommentOutput
Returns the content of a comment made on a change, file, or commit in a repository.
453 |
# File 'sig/client.rbs', line 453
def get_comment: (
|
#get_comment_reactions(params = {}) ⇒ Types::GetCommentReactionsOutput
Returns information about reactions to a specified comment ID. Reactions from users who have been deleted will not be included in the count.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
464 |
# File 'sig/client.rbs', line 464
def get_comment_reactions: (
|
#get_comments_for_compared_commit(params = {}) ⇒ Types::GetCommentsForComparedCommitOutput
Returns information about comments made on the comparison between two commits.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
478 |
# File 'sig/client.rbs', line 478
def get_comments_for_compared_commit: (
|
#get_comments_for_pull_request(params = {}) ⇒ Types::GetCommentsForPullRequestOutput
Returns comments made on a pull request.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
493 |
# File 'sig/client.rbs', line 493
def get_comments_for_pull_request: (
|
#get_commit(params = {}) ⇒ Types::GetCommitOutput
Returns information about a commit, including commit message and committer information.
508 |
# File 'sig/client.rbs', line 508
def get_commit: (
|
#get_differences(params = {}) ⇒ Types::GetDifferencesOutput
Returns information about the differences in a valid commit specifier (such as a branch, tag, HEAD, commit ID, or other fully qualified reference). Results can be limited to a specified path.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
520 |
# File 'sig/client.rbs', line 520
def get_differences: (
|
#get_file(params = {}) ⇒ Types::GetFileOutput
Returns the base-64 encoded contents of a specified file and its metadata.
541 |
# File 'sig/client.rbs', line 541
def get_file: (
|
#get_folder(params = {}) ⇒ Types::GetFolderOutput
Returns the contents of a specified folder in a repository.
559 |
# File 'sig/client.rbs', line 559
def get_folder: (
|
#get_merge_commit(params = {}) ⇒ Types::GetMergeCommitOutput
Returns information about a specified merge commit.
574 |
# File 'sig/client.rbs', line 574
def get_merge_commit: (
|
#get_merge_conflicts(params = {}) ⇒ Types::GetMergeConflictsOutput
Returns information about merge conflicts between the before and after commit IDs for a pull request in a repository.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
593 |
# File 'sig/client.rbs', line 593
def get_merge_conflicts: (
|
#get_merge_options(params = {}) ⇒ Types::GetMergeOptionsOutput
Returns information about the merge options available for merging two specified branches. For details about why a merge option is not available, use GetMergeConflicts or DescribeMergeConflicts.
613 |
# File 'sig/client.rbs', line 613
def get_merge_options: (
|
#get_pull_request(params = {}) ⇒ Types::GetPullRequestOutput
Gets information about a pull request in a specified repository.
627 |
# File 'sig/client.rbs', line 627
def get_pull_request: (
|
#get_pull_request_approval_states(params = {}) ⇒ Types::GetPullRequestApprovalStatesOutput
Gets information about the approval states for a specified pull request. Approval states only apply to pull requests that have one or more approval rules applied to them.
637 |
# File 'sig/client.rbs', line 637
def get_pull_request_approval_states: (
|
#get_pull_request_override_state(params = {}) ⇒ Types::GetPullRequestOverrideStateOutput
Returns information about whether approval rules have been set aside (overridden) for a pull request, and if so, the Amazon Resource Name (ARN) of the user or identity that overrode the rules and their requirements for the pull request.
649 |
# File 'sig/client.rbs', line 649
def get_pull_request_override_state: (
|
#get_repository(params = {}) ⇒ Types::GetRepositoryOutput
Returns information about a repository.
660 |
# File 'sig/client.rbs', line 660
def get_repository: (
|
#get_repository_triggers(params = {}) ⇒ Types::GetRepositoryTriggersOutput
Gets information about triggers configured for a repository.
671 |
# File 'sig/client.rbs', line 671
def get_repository_triggers: (
|
#list_approval_rule_templates(params = {}) ⇒ Types::ListApprovalRuleTemplatesOutput
Lists all approval rule templates in the specified Amazon Web Services Region in your Amazon Web Services account. If an Amazon Web Services Region is not specified, the Amazon Web Services Region where you are signed in is used.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
682 |
# File 'sig/client.rbs', line 682
def list_approval_rule_templates: (
|
#list_associated_approval_rule_templates_for_repository(params = {}) ⇒ Types::ListAssociatedApprovalRuleTemplatesForRepositoryOutput
Lists all approval rule templates that are associated with a specified repository.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
694 |
# File 'sig/client.rbs', line 694
def list_associated_approval_rule_templates_for_repository: (
|
#list_branches(params = {}) ⇒ Types::ListBranchesOutput
Gets information about one or more branches in a repository.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
707 |
# File 'sig/client.rbs', line 707
def list_branches: (
|
#list_file_commit_history(params = {}) ⇒ Types::ListFileCommitHistoryResponse
Retrieves a list of commits and changes to a specified file.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
719 |
# File 'sig/client.rbs', line 719
def list_file_commit_history: (
|
#list_pull_requests(params = {}) ⇒ Types::ListPullRequestsOutput
Returns a list of pull requests for a specified repository. The return list can be refined by pull request status or pull request author ARN.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
734 |
# File 'sig/client.rbs', line 734
def list_pull_requests: (
|
#list_repositories(params = {}) ⇒ Types::ListRepositoriesOutput
Gets information about one or more repositories.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
749 |
# File 'sig/client.rbs', line 749
def list_repositories: (
|
#list_repositories_for_approval_rule_template(params = {}) ⇒ Types::ListRepositoriesForApprovalRuleTemplateOutput
Lists all repositories associated with the specified approval rule template.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
762 |
# File 'sig/client.rbs', line 762
def list_repositories_for_approval_rule_template: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Gets information about Amazon Web Servicestags for a specified Amazon Resource Name (ARN) in CodeCommit. For a list of valid resources in CodeCommit, see CodeCommit Resources and Operations in the CodeCommit User Guide.
775 |
# File 'sig/client.rbs', line 775
def list_tags_for_resource: (
|
#merge_branches_by_fast_forward(params = {}) ⇒ Types::MergeBranchesByFastForwardOutput
Merges two branches using the fast-forward merge strategy.
787 |
# File 'sig/client.rbs', line 787
def merge_branches_by_fast_forward: (
|
#merge_branches_by_squash(params = {}) ⇒ Types::MergeBranchesBySquashOutput
Merges two branches using the squash merge strategy.
801 |
# File 'sig/client.rbs', line 801
def merge_branches_by_squash: (
|
#merge_branches_by_three_way(params = {}) ⇒ Types::MergeBranchesByThreeWayOutput
Merges two specified branches using the three-way merge strategy.
822 |
# File 'sig/client.rbs', line 822
def merge_branches_by_three_way: (
|
#merge_pull_request_by_fast_forward(params = {}) ⇒ Types::MergePullRequestByFastForwardOutput
Attempts to merge the source commit of a pull request into the specified destination branch for that pull request at the specified commit using the fast-forward merge strategy. If the merge is successful, it closes the pull request.
842 |
# File 'sig/client.rbs', line 842
def merge_pull_request_by_fast_forward: (
|
#merge_pull_request_by_squash(params = {}) ⇒ Types::MergePullRequestBySquashOutput
Attempts to merge the source commit of a pull request into the specified destination branch for that pull request at the specified commit using the squash merge strategy. If the merge is successful, it closes the pull request.
854 |
# File 'sig/client.rbs', line 854
def merge_pull_request_by_squash: (
|
#merge_pull_request_by_three_way(params = {}) ⇒ Types::MergePullRequestByThreeWayOutput
Attempts to merge the source commit of a pull request into the specified destination branch for that pull request at the specified commit using the three-way merge strategy. If the merge is successful, it closes the pull request.
873 |
# File 'sig/client.rbs', line 873
def merge_pull_request_by_three_way: (
|
#override_pull_request_approval_rules(params = {}) ⇒ Struct
Sets aside (overrides) all approval rule requirements for a specified pull request.
888 |
# File 'sig/client.rbs', line 888
def override_pull_request_approval_rules: (
|
#post_comment_for_compared_commit(params = {}) ⇒ Types::PostCommentForComparedCommitOutput
Posts a comment on the comparison between two commits.
906 |
# File 'sig/client.rbs', line 906
def post_comment_for_compared_commit: (
|
#post_comment_for_pull_request(params = {}) ⇒ Types::PostCommentForPullRequestOutput
Posts a comment on a pull request.
932 |
# File 'sig/client.rbs', line 932
def post_comment_for_pull_request: (
|
#post_comment_reply(params = {}) ⇒ Types::PostCommentReplyOutput
Posts a comment in reply to an existing comment on a comparison between commits or a pull request.
952 |
# File 'sig/client.rbs', line 952
def post_comment_reply: (
|
#put_comment_reaction(params = {}) ⇒ Struct
Adds or updates a reaction to a specified comment for the user whose identity is used to make the request. You can only add or update a reaction for yourself. You cannot add, modify, or delete a reaction for another user.
960 |
# File 'sig/client.rbs', line 960
def put_comment_reaction: (
|
#put_file(params = {}) ⇒ Types::PutFileOutput
Adds or updates a file in a branch in an CodeCommit repository, and generates a commit for the addition in the specified branch.
973 |
# File 'sig/client.rbs', line 973
def put_file: (
|
#put_repository_triggers(params = {}) ⇒ Types::PutRepositoryTriggersOutput
Replaces all triggers for a repository. Used to create or delete triggers.
991 |
# File 'sig/client.rbs', line 991
def put_repository_triggers: (
|
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a resource in CodeCommit. For a list of valid resources in CodeCommit, see CodeCommit Resources and Operations in the CodeCommit User Guide.
1006 |
# File 'sig/client.rbs', line 1006
def tag_resource: (
|
#test_repository_triggers(params = {}) ⇒ Types::TestRepositoryTriggersOutput
Tests the functionality of repository triggers by sending information to the trigger target. If real data is available in the repository, the test sends data from the last commit. If no data is available, sample data is generated.
1018 |
# File 'sig/client.rbs', line 1018
def test_repository_triggers: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags for a resource in CodeCommit. For a list of valid resources in CodeCommit, see CodeCommit Resources and Operations in the CodeCommit User Guide.
1033 |
# File 'sig/client.rbs', line 1033
def untag_resource: (
|
#update_approval_rule_template_content(params = {}) ⇒ Types::UpdateApprovalRuleTemplateContentOutput
Updates the content of an approval rule template. You can change the number of required approvals, the membership of the approval rule, and whether an approval pool is defined.
1044 |
# File 'sig/client.rbs', line 1044
def update_approval_rule_template_content: (
|
#update_approval_rule_template_description(params = {}) ⇒ Types::UpdateApprovalRuleTemplateDescriptionOutput
Updates the description for a specified approval rule template.
1056 |
# File 'sig/client.rbs', line 1056
def update_approval_rule_template_description: (
|
#update_approval_rule_template_name(params = {}) ⇒ Types::UpdateApprovalRuleTemplateNameOutput
Updates the name of a specified approval rule template.
1067 |
# File 'sig/client.rbs', line 1067
def update_approval_rule_template_name: (
|
#update_comment(params = {}) ⇒ Types::UpdateCommentOutput
Replaces the contents of a comment.
1078 |
# File 'sig/client.rbs', line 1078
def update_comment: (
|
#update_default_branch(params = {}) ⇒ Struct
Sets or changes the default branch name for the specified repository.
1085 |
# File 'sig/client.rbs', line 1085
def update_default_branch: (
|
#update_pull_request_approval_rule_content(params = {}) ⇒ Types::UpdatePullRequestApprovalRuleContentOutput
Updates the structure of an approval rule created specifically for a pull request. For example, you can change the number of required approvers and the approval pool for approvers.
1096 |
# File 'sig/client.rbs', line 1096
def update_pull_request_approval_rule_content: (
|
#update_pull_request_approval_state(params = {}) ⇒ Struct
Updates the state of a user's approval on a pull request. The user is derived from the signed-in account when the request is made.
1105 |
# File 'sig/client.rbs', line 1105
def update_pull_request_approval_state: (
|
#update_pull_request_description(params = {}) ⇒ Types::UpdatePullRequestDescriptionOutput
Replaces the contents of the description of a pull request.
1117 |
# File 'sig/client.rbs', line 1117
def update_pull_request_description: (
|
#update_pull_request_status(params = {}) ⇒ Types::UpdatePullRequestStatusOutput
Updates the status of a pull request.
1128 |
# File 'sig/client.rbs', line 1128
def update_pull_request_status: (
|
#update_pull_request_title(params = {}) ⇒ Types::UpdatePullRequestTitleOutput
Replaces the title of a pull request.
1139 |
# File 'sig/client.rbs', line 1139
def update_pull_request_title: (
|
#update_repository_description(params = {}) ⇒ Struct
Sets or changes the comment or description for a repository.
1146 |
# File 'sig/client.rbs', line 1146
def update_repository_description: (
|
#update_repository_encryption_key(params = {}) ⇒ Types::UpdateRepositoryEncryptionKeyOutput
Updates the Key Management Service encryption key used to encrypt and decrypt a CodeCommit repository.
1159 |
# File 'sig/client.rbs', line 1159
def update_repository_encryption_key: (
|
#update_repository_name(params = {}) ⇒ Struct
Renames a repository. The repository name must be unique across the calling Amazon Web Services account. Repository names are limited to 100 alphanumeric, dash, and underscore characters, and cannot include certain characters. The suffix .git is prohibited. For more information about the limits on repository names, see Quotas in the CodeCommit User Guide.
1166 |
# File 'sig/client.rbs', line 1166
def update_repository_name: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5216 5217 5218 |
# File 'lib/aws-sdk-codecommit/client.rb', line 5216 def waiter_names [] end |