Method: Aws::CodeCommit::Types::Comment#caller_reactions

Defined in:
lib/aws-sdk-codecommit/types.rb

#caller_reactionsArray<String>

The emoji reactions to a comment, if any, submitted by the user whose credentials are associated with the call to the API.

Returns:

  • (Array<String>)


908
909
910
911
912
913
914
915
916
917
918
919
920
921
# File 'lib/aws-sdk-codecommit/types.rb', line 908

class Comment < Struct.new(
  :comment_id,
  :content,
  :in_reply_to,
  :creation_date,
  :last_modified_date,
  :author_arn,
  :deleted,
  :client_request_token,
  :caller_reactions,
  :reaction_counts)
  SENSITIVE = []
  include Aws::Structure
end