Class: Aws::CodeCommit::Types::DiffHunk

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codecommit/types.rb

Overview

A contiguous run of changed lines from a blob diff, together with any surrounding unchanged context lines. Hunks are returned in order from the start of the file to the end. Adjacent or overlapping hunks are merged into a single hunk in the response.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#after_line_countInteger

The number of lines from the after blob covered by this hunk, including any context lines.

Returns:

  • (Integer)


2302
2303
2304
2305
2306
2307
2308
2309
2310
# File 'lib/aws-sdk-codecommit/types.rb', line 2302

class DiffHunk < Struct.new(
  :before_start_line,
  :before_line_count,
  :after_start_line,
  :after_line_count,
  :changes)
  SENSITIVE = []
  include Aws::Structure
end

#after_start_lineInteger

The 1-based line number in the after blob where this hunk begins. When the hunk consists entirely of deletions, afterLineCount is 0.

Returns:

  • (Integer)


2302
2303
2304
2305
2306
2307
2308
2309
2310
# File 'lib/aws-sdk-codecommit/types.rb', line 2302

class DiffHunk < Struct.new(
  :before_start_line,
  :before_line_count,
  :after_start_line,
  :after_line_count,
  :changes)
  SENSITIVE = []
  include Aws::Structure
end

#before_line_countInteger

The number of lines from the before blob covered by this hunk, including any context lines.

Returns:

  • (Integer)


2302
2303
2304
2305
2306
2307
2308
2309
2310
# File 'lib/aws-sdk-codecommit/types.rb', line 2302

class DiffHunk < Struct.new(
  :before_start_line,
  :before_line_count,
  :after_start_line,
  :after_line_count,
  :changes)
  SENSITIVE = []
  include Aws::Structure
end

#before_start_lineInteger

The 1-based line number in the before blob where this hunk begins. When the hunk consists entirely of additions, beforeLineCount is 0.

Returns:

  • (Integer)


2302
2303
2304
2305
2306
2307
2308
2309
2310
# File 'lib/aws-sdk-codecommit/types.rb', line 2302

class DiffHunk < Struct.new(
  :before_start_line,
  :before_line_count,
  :after_start_line,
  :after_line_count,
  :changes)
  SENSITIVE = []
  include Aws::Structure
end

#changesArray<Types::DiffChange>

An ordered list of line-level changes that make up this hunk. Each entry indicates whether the line is unchanged context, an addition, or a deletion.

Returns:



2302
2303
2304
2305
2306
2307
2308
2309
2310
# File 'lib/aws-sdk-codecommit/types.rb', line 2302

class DiffHunk < Struct.new(
  :before_start_line,
  :before_line_count,
  :after_start_line,
  :after_line_count,
  :changes)
  SENSITIVE = []
  include Aws::Structure
end