Class: Aws::CodeCommit::Types::EvaluatePullRequestApprovalRulesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeCommit::Types::EvaluatePullRequestApprovalRulesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codecommit/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#evaluation ⇒ Types::Evaluation
The result of the evaluation, including the names of the rules whose conditions have been met (if any), the names of the rules whose conditions have not been met (if any), whether the pull request is in the approved state, and whether the pull request approval rule has been set aside by an override.
Instance Attribute Details
#evaluation ⇒ Types::Evaluation
The result of the evaluation, including the names of the rules whose conditions have been met (if any), the names of the rules whose conditions have not been met (if any), whether the pull request is in the approved state, and whether the pull request approval rule has been set aside by an override.
2445 2446 2447 2448 2449 |
# File 'lib/aws-sdk-codecommit/types.rb', line 2445 class EvaluatePullRequestApprovalRulesOutput < Struct.new( :evaluation) SENSITIVE = [] include Aws::Structure end |