Method: Aws::CodeCommit::Types::Evaluation#overridden

Defined in:
lib/aws-sdk-codecommit/types.rb

#overriddenBoolean

Whether the approval rule requirements for the pull request have been overridden and no longer need to be met.

Returns:

  • (Boolean)


2390
2391
2392
2393
2394
2395
2396
2397
# File 'lib/aws-sdk-codecommit/types.rb', line 2390

class Evaluation < Struct.new(
  :approved,
  :overridden,
  :approval_rules_satisfied,
  :approval_rules_not_satisfied)
  SENSITIVE = []
  include Aws::Structure
end