Class: Aws::CodeCommit::Types::FileVersion
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeCommit::Types::FileVersion
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codecommit/types.rb
Overview
Information about a version of a file.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#blob_id ⇒ String
The blob ID of the object that represents the content of the file in this version.
-
#commit ⇒ Types::Commit
Returns information about a specific commit.
-
#path ⇒ String
The name and path of the file at which this blob is indexed which contains the data for this version of the file.
-
#revision_children ⇒ Array<String>
An array of commit IDs that contain more recent versions of this file.
Instance Attribute Details
#blob_id ⇒ String
The blob ID of the object that represents the content of the file in this version.
2688 2689 2690 2691 2692 2693 2694 2695 |
# File 'lib/aws-sdk-codecommit/types.rb', line 2688 class FileVersion < Struct.new( :commit, :blob_id, :path, :revision_children) SENSITIVE = [] include Aws::Structure end |
#commit ⇒ Types::Commit
Returns information about a specific commit.
2688 2689 2690 2691 2692 2693 2694 2695 |
# File 'lib/aws-sdk-codecommit/types.rb', line 2688 class FileVersion < Struct.new( :commit, :blob_id, :path, :revision_children) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The name and path of the file at which this blob is indexed which contains the data for this version of the file. This value will vary between file versions if a file is renamed or if its path changes.
2688 2689 2690 2691 2692 2693 2694 2695 |
# File 'lib/aws-sdk-codecommit/types.rb', line 2688 class FileVersion < Struct.new( :commit, :blob_id, :path, :revision_children) SENSITIVE = [] include Aws::Structure end |
#revision_children ⇒ Array<String>
An array of commit IDs that contain more recent versions of this file. If there are no additional versions of the file, this array will be empty.
2688 2689 2690 2691 2692 2693 2694 2695 |
# File 'lib/aws-sdk-codecommit/types.rb', line 2688 class FileVersion < Struct.new( :commit, :blob_id, :path, :revision_children) SENSITIVE = [] include Aws::Structure end |