Class: Aws::CodeCommit::Types::GetBranchInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codecommit/types.rb

Overview

Represents the input of a get branch operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#branch_nameString

The name of the branch for which you want to retrieve information.

Returns:

  • (String)


2907
2908
2909
2910
2911
2912
# File 'lib/aws-sdk-codecommit/types.rb', line 2907

class GetBranchInput < Struct.new(
  :repository_name,
  :branch_name)
  SENSITIVE = []
  include Aws::Structure
end

#repository_nameString

The name of the repository that contains the branch for which you want to retrieve information.

Returns:

  • (String)


2907
2908
2909
2910
2911
2912
# File 'lib/aws-sdk-codecommit/types.rb', line 2907

class GetBranchInput < Struct.new(
  :repository_name,
  :branch_name)
  SENSITIVE = []
  include Aws::Structure
end