Class: Aws::CodeCommit::Types::GetCommentsForComparedCommitInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeCommit::Types::GetCommentsForComparedCommitInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codecommit/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#after_commit_id ⇒ String
To establish the directionality of the comparison, the full commit ID of the after commit.
-
#before_commit_id ⇒ String
To establish the directionality of the comparison, the full commit ID of the before commit.
-
#max_results ⇒ Integer
A non-zero, non-negative integer used to limit the number of returned results.
-
#next_token ⇒ String
An enumeration token that when provided in a request, returns the next batch of the results.
-
#repository_name ⇒ String
The name of the repository where you want to compare commits.
Instance Attribute Details
#after_commit_id ⇒ String
To establish the directionality of the comparison, the full commit ID of the after commit.
3030 3031 3032 3033 3034 3035 3036 3037 3038 |
# File 'lib/aws-sdk-codecommit/types.rb', line 3030 class GetCommentsForComparedCommitInput < Struct.new( :repository_name, :before_commit_id, :after_commit_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#before_commit_id ⇒ String
To establish the directionality of the comparison, the full commit ID of the before commit.
3030 3031 3032 3033 3034 3035 3036 3037 3038 |
# File 'lib/aws-sdk-codecommit/types.rb', line 3030 class GetCommentsForComparedCommitInput < Struct.new( :repository_name, :before_commit_id, :after_commit_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
A non-zero, non-negative integer used to limit the number of returned results. The default is 100 comments, but you can configure up to 500.
3030 3031 3032 3033 3034 3035 3036 3037 3038 |
# File 'lib/aws-sdk-codecommit/types.rb', line 3030 class GetCommentsForComparedCommitInput < Struct.new( :repository_name, :before_commit_id, :after_commit_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An enumeration token that when provided in a request, returns the next batch of the results.
3030 3031 3032 3033 3034 3035 3036 3037 3038 |
# File 'lib/aws-sdk-codecommit/types.rb', line 3030 class GetCommentsForComparedCommitInput < Struct.new( :repository_name, :before_commit_id, :after_commit_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#repository_name ⇒ String
The name of the repository where you want to compare commits.
3030 3031 3032 3033 3034 3035 3036 3037 3038 |
# File 'lib/aws-sdk-codecommit/types.rb', line 3030 class GetCommentsForComparedCommitInput < Struct.new( :repository_name, :before_commit_id, :after_commit_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |