Class: Aws::CodeCommit::Types::GetCommentsForComparedCommitOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeCommit::Types::GetCommentsForComparedCommitOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codecommit/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#comments_for_compared_commit_data ⇒ Array<Types::CommentsForComparedCommit>
A list of comment objects on the compared commit.
-
#next_token ⇒ String
An enumeration token that can be used in a request to return the next batch of the results.
Instance Attribute Details
#comments_for_compared_commit_data ⇒ Array<Types::CommentsForComparedCommit>
A list of comment objects on the compared commit.
3051 3052 3053 3054 3055 3056 |
# File 'lib/aws-sdk-codecommit/types.rb', line 3051 class GetCommentsForComparedCommitOutput < Struct.new( :comments_for_compared_commit_data, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An enumeration token that can be used in a request to return the next batch of the results.
3051 3052 3053 3054 3055 3056 |
# File 'lib/aws-sdk-codecommit/types.rb', line 3051 class GetCommentsForComparedCommitOutput < Struct.new( :comments_for_compared_commit_data, :next_token) SENSITIVE = [] include Aws::Structure end |