Class: Aws::CodeCommit::Types::GetDifferencesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codecommit/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#after_commit_specifierString

The branch, tag, HEAD, or other fully qualified reference used to identify a commit.

Returns:

  • (String)


3202
3203
3204
3205
3206
3207
3208
3209
3210
3211
3212
# File 'lib/aws-sdk-codecommit/types.rb', line 3202

class GetDifferencesInput < Struct.new(
  :repository_name,
  :before_commit_specifier,
  :after_commit_specifier,
  :before_path,
  :after_path,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#after_pathString

The file path in which to check differences. Limits the results to this path. Can also be used to specify the changed name of a directory or folder, if it has changed. If not specified, differences are shown for all paths.

Returns:

  • (String)


3202
3203
3204
3205
3206
3207
3208
3209
3210
3211
3212
# File 'lib/aws-sdk-codecommit/types.rb', line 3202

class GetDifferencesInput < Struct.new(
  :repository_name,
  :before_commit_specifier,
  :after_commit_specifier,
  :before_path,
  :after_path,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#before_commit_specifierString

The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, the full commit ID). Optional. If not specified, all changes before the afterCommitSpecifier value are shown. If you do not use beforeCommitSpecifier in your request, consider limiting the results with maxResults.

Returns:

  • (String)


3202
3203
3204
3205
3206
3207
3208
3209
3210
3211
3212
# File 'lib/aws-sdk-codecommit/types.rb', line 3202

class GetDifferencesInput < Struct.new(
  :repository_name,
  :before_commit_specifier,
  :after_commit_specifier,
  :before_path,
  :after_path,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#before_pathString

The file path in which to check for differences. Limits the results to this path. Can also be used to specify the previous name of a directory or folder. If beforePath and afterPath are not specified, differences are shown for all paths.

Returns:

  • (String)


3202
3203
3204
3205
3206
3207
3208
3209
3210
3211
3212
# File 'lib/aws-sdk-codecommit/types.rb', line 3202

class GetDifferencesInput < Struct.new(
  :repository_name,
  :before_commit_specifier,
  :after_commit_specifier,
  :before_path,
  :after_path,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

A non-zero, non-negative integer used to limit the number of returned results.

Returns:

  • (Integer)


3202
3203
3204
3205
3206
3207
3208
3209
3210
3211
3212
# File 'lib/aws-sdk-codecommit/types.rb', line 3202

class GetDifferencesInput < Struct.new(
  :repository_name,
  :before_commit_specifier,
  :after_commit_specifier,
  :before_path,
  :after_path,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

An enumeration token that, when provided in a request, returns the next batch of the results.

Returns:

  • (String)


3202
3203
3204
3205
3206
3207
3208
3209
3210
3211
3212
# File 'lib/aws-sdk-codecommit/types.rb', line 3202

class GetDifferencesInput < Struct.new(
  :repository_name,
  :before_commit_specifier,
  :after_commit_specifier,
  :before_path,
  :after_path,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#repository_nameString

The name of the repository where you want to get differences.

Returns:

  • (String)


3202
3203
3204
3205
3206
3207
3208
3209
3210
3211
3212
# File 'lib/aws-sdk-codecommit/types.rb', line 3202

class GetDifferencesInput < Struct.new(
  :repository_name,
  :before_commit_specifier,
  :after_commit_specifier,
  :before_path,
  :after_path,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end