Class: Aws::CodeCommit::Types::GetDifferencesOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codecommit/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#differencesArray<Types::Difference>

A data type object that contains information about the differences, including whether the difference is added, modified, or deleted (A, D, M).

Returns:



3227
3228
3229
3230
3231
3232
# File 'lib/aws-sdk-codecommit/types.rb', line 3227

class GetDifferencesOutput < Struct.new(
  :differences,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

An enumeration token that can be used in a request to return the next batch of the results.

Returns:

  • (String)


3227
3228
3229
3230
3231
3232
# File 'lib/aws-sdk-codecommit/types.rb', line 3227

class GetDifferencesOutput < Struct.new(
  :differences,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end