Class: Aws::CodeCommit::Types::MergeBranchesBySquashInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeCommit::Types::MergeBranchesBySquashInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codecommit/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#author_name ⇒ String
The name of the author who created the commit.
-
#commit_message ⇒ String
The commit message for the merge.
-
#conflict_detail_level ⇒ String
The level of conflict detail to use.
-
#conflict_resolution ⇒ Types::ConflictResolution
If AUTOMERGE is the conflict resolution strategy, a list of inputs to use when resolving conflicts during a merge.
-
#conflict_resolution_strategy ⇒ String
Specifies which branch to use when resolving conflicts, or whether to attempt automatically merging two versions of a file.
-
#destination_commit_specifier ⇒ String
The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
-
#email ⇒ String
The email address of the person merging the branches.
-
#keep_empty_folders ⇒ Boolean
If the commit contains deletions, whether to keep a folder or folder structure if the changes leave the folders empty.
-
#repository_name ⇒ String
The name of the repository where you want to merge two branches.
-
#source_commit_specifier ⇒ String
The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
-
#target_branch ⇒ String
The branch where the merge is applied.
Instance Attribute Details
#author_name ⇒ String
The name of the author who created the commit. This information is used as both the author and committer for the commit.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 |
# File 'lib/aws-sdk-codecommit/types.rb', line 4850 class MergeBranchesBySquashInput < Struct.new( :repository_name, :source_commit_specifier, :destination_commit_specifier, :target_branch, :conflict_detail_level, :conflict_resolution_strategy, :author_name, :email, :commit_message, :keep_empty_folders, :conflict_resolution) SENSITIVE = [] include Aws::Structure end |
#commit_message ⇒ String
The commit message for the merge.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 |
# File 'lib/aws-sdk-codecommit/types.rb', line 4850 class MergeBranchesBySquashInput < Struct.new( :repository_name, :source_commit_specifier, :destination_commit_specifier, :target_branch, :conflict_detail_level, :conflict_resolution_strategy, :author_name, :email, :commit_message, :keep_empty_folders, :conflict_resolution) SENSITIVE = [] include Aws::Structure end |
#conflict_detail_level ⇒ String
The level of conflict detail to use. If unspecified, the default FILE_LEVEL is used, which returns a not-mergeable result if the same file has differences in both branches. If LINE_LEVEL is specified, a conflict is considered not mergeable if the same file in both branches has differences on the same line.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 |
# File 'lib/aws-sdk-codecommit/types.rb', line 4850 class MergeBranchesBySquashInput < Struct.new( :repository_name, :source_commit_specifier, :destination_commit_specifier, :target_branch, :conflict_detail_level, :conflict_resolution_strategy, :author_name, :email, :commit_message, :keep_empty_folders, :conflict_resolution) SENSITIVE = [] include Aws::Structure end |
#conflict_resolution ⇒ Types::ConflictResolution
If AUTOMERGE is the conflict resolution strategy, a list of inputs to use when resolving conflicts during a merge.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 |
# File 'lib/aws-sdk-codecommit/types.rb', line 4850 class MergeBranchesBySquashInput < Struct.new( :repository_name, :source_commit_specifier, :destination_commit_specifier, :target_branch, :conflict_detail_level, :conflict_resolution_strategy, :author_name, :email, :commit_message, :keep_empty_folders, :conflict_resolution) SENSITIVE = [] include Aws::Structure end |
#conflict_resolution_strategy ⇒ String
Specifies which branch to use when resolving conflicts, or whether to attempt automatically merging two versions of a file. The default is NONE, which requires any conflicts to be resolved manually before the merge operation is successful.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 |
# File 'lib/aws-sdk-codecommit/types.rb', line 4850 class MergeBranchesBySquashInput < Struct.new( :repository_name, :source_commit_specifier, :destination_commit_specifier, :target_branch, :conflict_detail_level, :conflict_resolution_strategy, :author_name, :email, :commit_message, :keep_empty_folders, :conflict_resolution) SENSITIVE = [] include Aws::Structure end |
#destination_commit_specifier ⇒ String
The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 |
# File 'lib/aws-sdk-codecommit/types.rb', line 4850 class MergeBranchesBySquashInput < Struct.new( :repository_name, :source_commit_specifier, :destination_commit_specifier, :target_branch, :conflict_detail_level, :conflict_resolution_strategy, :author_name, :email, :commit_message, :keep_empty_folders, :conflict_resolution) SENSITIVE = [] include Aws::Structure end |
#email ⇒ String
The email address of the person merging the branches. This information is used in the commit information for the merge.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 |
# File 'lib/aws-sdk-codecommit/types.rb', line 4850 class MergeBranchesBySquashInput < Struct.new( :repository_name, :source_commit_specifier, :destination_commit_specifier, :target_branch, :conflict_detail_level, :conflict_resolution_strategy, :author_name, :email, :commit_message, :keep_empty_folders, :conflict_resolution) SENSITIVE = [] include Aws::Structure end |
#keep_empty_folders ⇒ Boolean
If the commit contains deletions, whether to keep a folder or folder structure if the changes leave the folders empty. If this is specified as true, a .gitkeep file is created for empty folders. The default is false.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 |
# File 'lib/aws-sdk-codecommit/types.rb', line 4850 class MergeBranchesBySquashInput < Struct.new( :repository_name, :source_commit_specifier, :destination_commit_specifier, :target_branch, :conflict_detail_level, :conflict_resolution_strategy, :author_name, :email, :commit_message, :keep_empty_folders, :conflict_resolution) SENSITIVE = [] include Aws::Structure end |
#repository_name ⇒ String
The name of the repository where you want to merge two branches.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 |
# File 'lib/aws-sdk-codecommit/types.rb', line 4850 class MergeBranchesBySquashInput < Struct.new( :repository_name, :source_commit_specifier, :destination_commit_specifier, :target_branch, :conflict_detail_level, :conflict_resolution_strategy, :author_name, :email, :commit_message, :keep_empty_folders, :conflict_resolution) SENSITIVE = [] include Aws::Structure end |
#source_commit_specifier ⇒ String
The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 |
# File 'lib/aws-sdk-codecommit/types.rb', line 4850 class MergeBranchesBySquashInput < Struct.new( :repository_name, :source_commit_specifier, :destination_commit_specifier, :target_branch, :conflict_detail_level, :conflict_resolution_strategy, :author_name, :email, :commit_message, :keep_empty_folders, :conflict_resolution) SENSITIVE = [] include Aws::Structure end |
#target_branch ⇒ String
The branch where the merge is applied.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 |
# File 'lib/aws-sdk-codecommit/types.rb', line 4850 class MergeBranchesBySquashInput < Struct.new( :repository_name, :source_commit_specifier, :destination_commit_specifier, :target_branch, :conflict_detail_level, :conflict_resolution_strategy, :author_name, :email, :commit_message, :keep_empty_folders, :conflict_resolution) SENSITIVE = [] include Aws::Structure end |