Class: Aws::CodeCommit::Types::MergePullRequestByFastForwardInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codecommit/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#pull_request_idString

The system-generated ID of the pull request. To get this ID, use ListPullRequests.

Returns:

  • (String)


5115
5116
5117
5118
5119
5120
5121
# File 'lib/aws-sdk-codecommit/types.rb', line 5115

class MergePullRequestByFastForwardInput < Struct.new(
  :pull_request_id,
  :repository_name,
  :source_commit_id)
  SENSITIVE = []
  include Aws::Structure
end

#repository_nameString

The name of the repository where the pull request was created.

Returns:

  • (String)


5115
5116
5117
5118
5119
5120
5121
# File 'lib/aws-sdk-codecommit/types.rb', line 5115

class MergePullRequestByFastForwardInput < Struct.new(
  :pull_request_id,
  :repository_name,
  :source_commit_id)
  SENSITIVE = []
  include Aws::Structure
end

#source_commit_idString

The full commit ID of the original or updated commit in the pull request source branch. Pass this value if you want an exception thrown if the current commit ID of the tip of the source branch does not match this commit ID.

Returns:

  • (String)


5115
5116
5117
5118
5119
5120
5121
# File 'lib/aws-sdk-codecommit/types.rb', line 5115

class MergePullRequestByFastForwardInput < Struct.new(
  :pull_request_id,
  :repository_name,
  :source_commit_id)
  SENSITIVE = []
  include Aws::Structure
end