Class: Aws::CodeCommit::Types::PostCommentForPullRequestOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codecommit/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#after_blob_idString

In the directionality of the pull request, the blob ID of the after blob.

Returns:

  • (String)


5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-codecommit/types.rb', line 5672

class PostCommentForPullRequestOutput < Struct.new(
  :repository_name,
  :pull_request_id,
  :before_commit_id,
  :after_commit_id,
  :before_blob_id,
  :after_blob_id,
  :location,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end

#after_commit_idString

The full commit ID of the commit in the destination branch where the pull request is merged.

Returns:

  • (String)


5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-codecommit/types.rb', line 5672

class PostCommentForPullRequestOutput < Struct.new(
  :repository_name,
  :pull_request_id,
  :before_commit_id,
  :after_commit_id,
  :before_blob_id,
  :after_blob_id,
  :location,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end

#before_blob_idString

In the directionality of the pull request, the blob ID of the before blob.

Returns:

  • (String)


5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-codecommit/types.rb', line 5672

class PostCommentForPullRequestOutput < Struct.new(
  :repository_name,
  :pull_request_id,
  :before_commit_id,
  :after_commit_id,
  :before_blob_id,
  :after_blob_id,
  :location,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end

#before_commit_idString

The full commit ID of the commit in the source branch used to create the pull request, or in the case of an updated pull request, the full commit ID of the commit used to update the pull request.

Returns:

  • (String)


5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-codecommit/types.rb', line 5672

class PostCommentForPullRequestOutput < Struct.new(
  :repository_name,
  :pull_request_id,
  :before_commit_id,
  :after_commit_id,
  :before_blob_id,
  :after_blob_id,
  :location,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end

#commentTypes::Comment

The content of the comment you posted.

Returns:



5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-codecommit/types.rb', line 5672

class PostCommentForPullRequestOutput < Struct.new(
  :repository_name,
  :pull_request_id,
  :before_commit_id,
  :after_commit_id,
  :before_blob_id,
  :after_blob_id,
  :location,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end

#locationTypes::Location

The location of the change where you posted your comment.

Returns:



5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-codecommit/types.rb', line 5672

class PostCommentForPullRequestOutput < Struct.new(
  :repository_name,
  :pull_request_id,
  :before_commit_id,
  :after_commit_id,
  :before_blob_id,
  :after_blob_id,
  :location,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end

#pull_request_idString

The system-generated ID of the pull request.

Returns:

  • (String)


5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-codecommit/types.rb', line 5672

class PostCommentForPullRequestOutput < Struct.new(
  :repository_name,
  :pull_request_id,
  :before_commit_id,
  :after_commit_id,
  :before_blob_id,
  :after_blob_id,
  :location,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end

#repository_nameString

The name of the repository where you posted a comment on a pull request.

Returns:

  • (String)


5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/aws-sdk-codecommit/types.rb', line 5672

class PostCommentForPullRequestOutput < Struct.new(
  :repository_name,
  :pull_request_id,
  :before_commit_id,
  :after_commit_id,
  :before_blob_id,
  :after_blob_id,
  :location,
  :comment)
  SENSITIVE = []
  include Aws::Structure
end