Class: Aws::CodeCommit::Types::PutFileEntry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codecommit/types.rb

Overview

Information about a file added or updated as part of a commit.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#file_contentString

The content of the file, if a source file is not specified.

Returns:

  • (String)


6123
6124
6125
6126
6127
6128
6129
6130
# File 'lib/aws-sdk-codecommit/types.rb', line 6123

class PutFileEntry < Struct.new(
  :file_path,
  :file_mode,
  :file_content,
  :source_file)
  SENSITIVE = []
  include Aws::Structure
end

#file_modeString

The extrapolated file mode permissions for the file. Valid values include EXECUTABLE and NORMAL.

Returns:

  • (String)


6123
6124
6125
6126
6127
6128
6129
6130
# File 'lib/aws-sdk-codecommit/types.rb', line 6123

class PutFileEntry < Struct.new(
  :file_path,
  :file_mode,
  :file_content,
  :source_file)
  SENSITIVE = []
  include Aws::Structure
end

#file_pathString

The full path to the file in the repository, including the name of the file.

Returns:

  • (String)


6123
6124
6125
6126
6127
6128
6129
6130
# File 'lib/aws-sdk-codecommit/types.rb', line 6123

class PutFileEntry < Struct.new(
  :file_path,
  :file_mode,
  :file_content,
  :source_file)
  SENSITIVE = []
  include Aws::Structure
end

#source_fileTypes::SourceFileSpecifier

The name and full path of the file that contains the changes you want to make as part of the commit, if you are not providing the file content directly.



6123
6124
6125
6126
6127
6128
6129
6130
# File 'lib/aws-sdk-codecommit/types.rb', line 6123

class PutFileEntry < Struct.new(
  :file_path,
  :file_mode,
  :file_content,
  :source_file)
  SENSITIVE = []
  include Aws::Structure
end