Class: Aws::CodeCommit::Types::PutFileInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codecommit/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#branch_nameString

The name of the branch where you want to add or update the file. If this is an empty repository, this branch is created.

Returns:

  • (String)


6196
6197
6198
6199
6200
6201
6202
6203
6204
6205
6206
6207
6208
# File 'lib/aws-sdk-codecommit/types.rb', line 6196

class PutFileInput < Struct.new(
  :repository_name,
  :branch_name,
  :file_content,
  :file_path,
  :file_mode,
  :parent_commit_id,
  :commit_message,
  :name,
  :email)
  SENSITIVE = []
  include Aws::Structure
end

#commit_messageString

A message about why this file was added or updated. Although it is optional, a message makes the commit history for your repository more useful.

Returns:

  • (String)


6196
6197
6198
6199
6200
6201
6202
6203
6204
6205
6206
6207
6208
# File 'lib/aws-sdk-codecommit/types.rb', line 6196

class PutFileInput < Struct.new(
  :repository_name,
  :branch_name,
  :file_content,
  :file_path,
  :file_mode,
  :parent_commit_id,
  :commit_message,
  :name,
  :email)
  SENSITIVE = []
  include Aws::Structure
end

#emailString

An email address for the person adding or updating the file.

Returns:

  • (String)


6196
6197
6198
6199
6200
6201
6202
6203
6204
6205
6206
6207
6208
# File 'lib/aws-sdk-codecommit/types.rb', line 6196

class PutFileInput < Struct.new(
  :repository_name,
  :branch_name,
  :file_content,
  :file_path,
  :file_mode,
  :parent_commit_id,
  :commit_message,
  :name,
  :email)
  SENSITIVE = []
  include Aws::Structure
end

#file_contentString

The content of the file, in binary object format.

Returns:

  • (String)


6196
6197
6198
6199
6200
6201
6202
6203
6204
6205
6206
6207
6208
# File 'lib/aws-sdk-codecommit/types.rb', line 6196

class PutFileInput < Struct.new(
  :repository_name,
  :branch_name,
  :file_content,
  :file_path,
  :file_mode,
  :parent_commit_id,
  :commit_message,
  :name,
  :email)
  SENSITIVE = []
  include Aws::Structure
end

#file_modeString

The file mode permissions of the blob. Valid file mode permissions are listed here.

Returns:

  • (String)


6196
6197
6198
6199
6200
6201
6202
6203
6204
6205
6206
6207
6208
# File 'lib/aws-sdk-codecommit/types.rb', line 6196

class PutFileInput < Struct.new(
  :repository_name,
  :branch_name,
  :file_content,
  :file_path,
  :file_mode,
  :parent_commit_id,
  :commit_message,
  :name,
  :email)
  SENSITIVE = []
  include Aws::Structure
end

#file_pathString

The name of the file you want to add or update, including the relative path to the file in the repository.

If the path does not currently exist in the repository, the path is created as part of adding the file.

Returns:

  • (String)


6196
6197
6198
6199
6200
6201
6202
6203
6204
6205
6206
6207
6208
# File 'lib/aws-sdk-codecommit/types.rb', line 6196

class PutFileInput < Struct.new(
  :repository_name,
  :branch_name,
  :file_content,
  :file_path,
  :file_mode,
  :parent_commit_id,
  :commit_message,
  :name,
  :email)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the person adding or updating the file. Although it is optional, a name makes the commit history for your repository more useful.

Returns:

  • (String)


6196
6197
6198
6199
6200
6201
6202
6203
6204
6205
6206
6207
6208
# File 'lib/aws-sdk-codecommit/types.rb', line 6196

class PutFileInput < Struct.new(
  :repository_name,
  :branch_name,
  :file_content,
  :file_path,
  :file_mode,
  :parent_commit_id,
  :commit_message,
  :name,
  :email)
  SENSITIVE = []
  include Aws::Structure
end

#parent_commit_idString

The full commit ID of the head commit in the branch where you want to add or update the file. If this is an empty repository, no commit ID is required. If this is not an empty repository, a commit ID is required.

The commit ID must match the ID of the head commit at the time of the operation. Otherwise, an error occurs, and the file is not added or updated.

Returns:

  • (String)


6196
6197
6198
6199
6200
6201
6202
6203
6204
6205
6206
6207
6208
# File 'lib/aws-sdk-codecommit/types.rb', line 6196

class PutFileInput < Struct.new(
  :repository_name,
  :branch_name,
  :file_content,
  :file_path,
  :file_mode,
  :parent_commit_id,
  :commit_message,
  :name,
  :email)
  SENSITIVE = []
  include Aws::Structure
end

#repository_nameString

The name of the repository where you want to add or update the file.

Returns:

  • (String)


6196
6197
6198
6199
6200
6201
6202
6203
6204
6205
6206
6207
6208
# File 'lib/aws-sdk-codecommit/types.rb', line 6196

class PutFileInput < Struct.new(
  :repository_name,
  :branch_name,
  :file_content,
  :file_path,
  :file_mode,
  :parent_commit_id,
  :commit_message,
  :name,
  :email)
  SENSITIVE = []
  include Aws::Structure
end