Class: Aws::CodeCommit::Types::ReactionForComment
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeCommit::Types::ReactionForComment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codecommit/types.rb
Overview
Information about the reaction values provided by users on a comment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#reaction ⇒ Types::ReactionValueFormats
The reaction for a specified comment.
-
#reaction_users ⇒ Array<String>
The Amazon Resource Names (ARNs) of users who have provided reactions to the comment.
-
#reactions_from_deleted_users_count ⇒ Integer
A numerical count of users who reacted with the specified emoji whose identities have been subsequently deleted from IAM.
Instance Attribute Details
#reaction ⇒ Types::ReactionValueFormats
The reaction for a specified comment.
6287 6288 6289 6290 6291 6292 6293 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6287 class ReactionForComment < Struct.new( :reaction, :reaction_users, :reactions_from_deleted_users_count) SENSITIVE = [] include Aws::Structure end |
#reaction_users ⇒ Array<String>
The Amazon Resource Names (ARNs) of users who have provided reactions to the comment.
6287 6288 6289 6290 6291 6292 6293 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6287 class ReactionForComment < Struct.new( :reaction, :reaction_users, :reactions_from_deleted_users_count) SENSITIVE = [] include Aws::Structure end |
#reactions_from_deleted_users_count ⇒ Integer
A numerical count of users who reacted with the specified emoji whose identities have been subsequently deleted from IAM. While these IAM users or roles no longer exist, the reactions might still appear in total reaction counts.
6287 6288 6289 6290 6291 6292 6293 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6287 class ReactionForComment < Struct.new( :reaction, :reaction_users, :reactions_from_deleted_users_count) SENSITIVE = [] include Aws::Structure end |