Class: Aws::CodeCommit::Types::RepositoryMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeCommit::Types::RepositoryMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codecommit/types.rb
Overview
Information about a repository.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ID of the Amazon Web Services account associated with the repository.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the repository.
-
#clone_url_http ⇒ String
The URL to use for cloning the repository over HTTPS.
-
#clone_url_ssh ⇒ String
The URL to use for cloning the repository over SSH.
-
#creation_date ⇒ Time
The date and time the repository was created, in timestamp format.
-
#default_branch ⇒ String
The repository's default branch name.
-
#kms_key_id ⇒ String
The ID of the Key Management Service encryption key used to encrypt and decrypt the repository.
-
#last_modified_date ⇒ Time
The date and time the repository was last modified, in timestamp format.
-
#repository_description ⇒ String
A comment or description about the repository.
-
#repository_id ⇒ String
The ID of the repository.
-
#repository_name ⇒ String
The repository's name.
Instance Attribute Details
#account_id ⇒ String
The ID of the Amazon Web Services account associated with the repository.
6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6462 class RepositoryMetadata < Struct.new( :account_id, :repository_id, :repository_name, :repository_description, :default_branch, :last_modified_date, :creation_date, :clone_url_http, :clone_url_ssh, :arn, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the repository.
6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6462 class RepositoryMetadata < Struct.new( :account_id, :repository_id, :repository_name, :repository_description, :default_branch, :last_modified_date, :creation_date, :clone_url_http, :clone_url_ssh, :arn, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#clone_url_http ⇒ String
The URL to use for cloning the repository over HTTPS.
6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6462 class RepositoryMetadata < Struct.new( :account_id, :repository_id, :repository_name, :repository_description, :default_branch, :last_modified_date, :creation_date, :clone_url_http, :clone_url_ssh, :arn, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#clone_url_ssh ⇒ String
The URL to use for cloning the repository over SSH.
6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6462 class RepositoryMetadata < Struct.new( :account_id, :repository_id, :repository_name, :repository_description, :default_branch, :last_modified_date, :creation_date, :clone_url_http, :clone_url_ssh, :arn, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date and time the repository was created, in timestamp format.
6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6462 class RepositoryMetadata < Struct.new( :account_id, :repository_id, :repository_name, :repository_description, :default_branch, :last_modified_date, :creation_date, :clone_url_http, :clone_url_ssh, :arn, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#default_branch ⇒ String
The repository's default branch name.
6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6462 class RepositoryMetadata < Struct.new( :account_id, :repository_id, :repository_name, :repository_description, :default_branch, :last_modified_date, :creation_date, :clone_url_http, :clone_url_ssh, :arn, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The ID of the Key Management Service encryption key used to encrypt and decrypt the repository.
6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6462 class RepositoryMetadata < Struct.new( :account_id, :repository_id, :repository_name, :repository_description, :default_branch, :last_modified_date, :creation_date, :clone_url_http, :clone_url_ssh, :arn, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Time
The date and time the repository was last modified, in timestamp format.
6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6462 class RepositoryMetadata < Struct.new( :account_id, :repository_id, :repository_name, :repository_description, :default_branch, :last_modified_date, :creation_date, :clone_url_http, :clone_url_ssh, :arn, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#repository_description ⇒ String
A comment or description about the repository.
6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6462 class RepositoryMetadata < Struct.new( :account_id, :repository_id, :repository_name, :repository_description, :default_branch, :last_modified_date, :creation_date, :clone_url_http, :clone_url_ssh, :arn, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#repository_id ⇒ String
The ID of the repository.
6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6462 class RepositoryMetadata < Struct.new( :account_id, :repository_id, :repository_name, :repository_description, :default_branch, :last_modified_date, :creation_date, :clone_url_http, :clone_url_ssh, :arn, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#repository_name ⇒ String
The repository's name.
6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6462 class RepositoryMetadata < Struct.new( :account_id, :repository_id, :repository_name, :repository_description, :default_branch, :last_modified_date, :creation_date, :clone_url_http, :clone_url_ssh, :arn, :kms_key_id) SENSITIVE = [] include Aws::Structure end |