Class: Aws::CodeCommit::Types::TestRepositoryTriggersInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codecommit/types.rb

Overview

Represents the input of a test repository triggers operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#repository_nameString

The name of the repository in which to test the triggers.

Returns:

  • (String)


6884
6885
6886
6887
6888
6889
# File 'lib/aws-sdk-codecommit/types.rb', line 6884

class TestRepositoryTriggersInput < Struct.new(
  :repository_name,
  :triggers)
  SENSITIVE = []
  include Aws::Structure
end

#triggersArray<Types::RepositoryTrigger>

The list of triggers to test.

Returns:



6884
6885
6886
6887
6888
6889
# File 'lib/aws-sdk-codecommit/types.rb', line 6884

class TestRepositoryTriggersInput < Struct.new(
  :repository_name,
  :triggers)
  SENSITIVE = []
  include Aws::Structure
end