Method: Aws::CodeCommit::Client#create_branch
- Defined in:
- lib/aws-sdk-codecommit/client.rb
#create_branch(params = {}) ⇒ Struct
Creates a branch in a repository and points the branch to a commit.
<note markdown=“1”> Calling the create branch operation does not set a repository’s default branch. To do this, call the update default branch operation.
</note>
969 970 971 972 |
# File 'lib/aws-sdk-codecommit/client.rb', line 969 def create_branch(params = {}, = {}) req = build_request(:create_branch, params) req.send_request() end |