Class: Aws::CodeCommit::Types::GetBlobDifferencesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeCommit::Types::GetBlobDifferencesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codecommit/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#after_blob_id ⇒ String
The ID of the "after" (destination) blob in the diff.
-
#before_blob_id ⇒ String
The ID of the "before" (source) blob in the diff.
-
#context_lines ⇒ Integer
The number of unchanged lines of context to include before and after each block of changes in a hunk.
-
#ignore_whitespace ⇒ Boolean
Specifies whether to ignore whitespace-only changes when computing the diff.
-
#max_results ⇒ Integer
The maximum number of
DiffHunkentries to return in a single response page. -
#next_token ⇒ String
An enumeration token that returns the next batch of results when present in a request.
-
#repository_name ⇒ String
The name of the repository that contains the blobs to compare.
Instance Attribute Details
#after_blob_id ⇒ String
The ID of the "after" (destination) blob in the diff. Typically
the value of afterBlob.blobId from a Difference object returned
by GetDifferences.
2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 2818 |
# File 'lib/aws-sdk-codecommit/types.rb', line 2808 class GetBlobDifferencesInput < Struct.new( :repository_name, :after_blob_id, :before_blob_id, :context_lines, :ignore_whitespace, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#before_blob_id ⇒ String
The ID of the "before" (source) blob in the diff. Typically the
value of beforeBlob.blobId from a Difference object returned by
GetDifferences.
If you do not specify a value, the operation returns a diff against an empty before-state. This is equivalent to treating the file as newly added.
2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 2818 |
# File 'lib/aws-sdk-codecommit/types.rb', line 2808 class GetBlobDifferencesInput < Struct.new( :repository_name, :after_blob_id, :before_blob_id, :context_lines, :ignore_whitespace, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#context_lines ⇒ Integer
The number of unchanged lines of context to include before and after
each block of changes in a hunk. Valid values are 0 through 20.
Defaults to 3.
2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 2818 |
# File 'lib/aws-sdk-codecommit/types.rb', line 2808 class GetBlobDifferencesInput < Struct.new( :repository_name, :after_blob_id, :before_blob_id, :context_lines, :ignore_whitespace, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#ignore_whitespace ⇒ Boolean
Specifies whether to ignore whitespace-only changes when computing
the diff. When true, the operation treats lines that differ only
in whitespace as unchanged. Defaults to false.
2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 2818 |
# File 'lib/aws-sdk-codecommit/types.rb', line 2808 class GetBlobDifferencesInput < Struct.new( :repository_name, :after_blob_id, :before_blob_id, :context_lines, :ignore_whitespace, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of DiffHunk entries to return in a single
response page. Defaults to 100.
2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 2818 |
# File 'lib/aws-sdk-codecommit/types.rb', line 2808 class GetBlobDifferencesInput < Struct.new( :repository_name, :after_blob_id, :before_blob_id, :context_lines, :ignore_whitespace, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An enumeration token that returns the next batch of results when present in a request.
2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 2818 |
# File 'lib/aws-sdk-codecommit/types.rb', line 2808 class GetBlobDifferencesInput < Struct.new( :repository_name, :after_blob_id, :before_blob_id, :context_lines, :ignore_whitespace, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#repository_name ⇒ String
The name of the repository that contains the blobs to compare.
2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 2818 |
# File 'lib/aws-sdk-codecommit/types.rb', line 2808 class GetBlobDifferencesInput < Struct.new( :repository_name, :after_blob_id, :before_blob_id, :context_lines, :ignore_whitespace, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |