Class: Aws::CodeCommit::Types::GetBlobDifferencesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeCommit::Types::GetBlobDifferencesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codecommit/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#after_blob_size ⇒ Integer
The size, in bytes, of the blob identified by
afterBlobId. -
#before_blob_size ⇒ Integer
The size, in bytes, of the blob identified by
beforeBlobId. -
#hunks ⇒ Array<Types::DiffHunk>
An ordered list of diff hunks.
-
#is_binary ⇒ Boolean
Specifies whether the operation treated the diff content as binary.
-
#next_token ⇒ String
An enumeration token that can be used in a request to return the next batch of
DiffHunkentries.
Instance Attribute Details
#after_blob_size ⇒ Integer
The size, in bytes, of the blob identified by afterBlobId.
2851 2852 2853 2854 2855 2856 2857 2858 2859 |
# File 'lib/aws-sdk-codecommit/types.rb', line 2851 class GetBlobDifferencesOutput < Struct.new( :hunks, :is_binary, :before_blob_size, :after_blob_size, :next_token) SENSITIVE = [] include Aws::Structure end |
#before_blob_size ⇒ Integer
The size, in bytes, of the blob identified by beforeBlobId.
Returns 0 when you do not specify beforeBlobId.
2851 2852 2853 2854 2855 2856 2857 2858 2859 |
# File 'lib/aws-sdk-codecommit/types.rb', line 2851 class GetBlobDifferencesOutput < Struct.new( :hunks, :is_binary, :before_blob_size, :after_blob_size, :next_token) SENSITIVE = [] include Aws::Structure end |
#hunks ⇒ Array<Types::DiffHunk>
An ordered list of diff hunks. Each hunk represents a contiguous run
of changed and adjacent context lines. The list is empty when the
blobs are identical or when the content is binary. The list is also
empty when a paginated request has already returned all hunks in
earlier pages, in which case NextToken is also null.
2851 2852 2853 2854 2855 2856 2857 2858 2859 |
# File 'lib/aws-sdk-codecommit/types.rb', line 2851 class GetBlobDifferencesOutput < Struct.new( :hunks, :is_binary, :before_blob_size, :after_blob_size, :next_token) SENSITIVE = [] include Aws::Structure end |
#is_binary ⇒ Boolean
Specifies whether the operation treated the diff content as binary.
When true, the operation does not compute a line-level diff and
hunks is empty.
2851 2852 2853 2854 2855 2856 2857 2858 2859 |
# File 'lib/aws-sdk-codecommit/types.rb', line 2851 class GetBlobDifferencesOutput < Struct.new( :hunks, :is_binary, :before_blob_size, :after_blob_size, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An enumeration token that can be used in a request to return the
next batch of DiffHunk entries. null when the response contains
the final page of the diff.
2851 2852 2853 2854 2855 2856 2857 2858 2859 |
# File 'lib/aws-sdk-codecommit/types.rb', line 2851 class GetBlobDifferencesOutput < Struct.new( :hunks, :is_binary, :before_blob_size, :after_blob_size, :next_token) SENSITIVE = [] include Aws::Structure end |