Class: Aws::CodeCommit::Types::GetDifferencesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeCommit::Types::GetDifferencesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codecommit/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#after_commit_specifier ⇒ String
The branch, tag, HEAD, or other fully qualified reference used to identify a commit.
-
#after_path ⇒ String
The file path in which to check differences.
-
#before_commit_specifier ⇒ String
The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, the full commit ID).
-
#before_path ⇒ String
The file path in which to check for differences.
-
#max_results ⇒ Integer
A non-zero, non-negative integer used to limit the number of returned results.
-
#next_token ⇒ String
An enumeration token that, when provided in a request, returns the next batch of the results.
-
#repository_name ⇒ String
The name of the repository where you want to get differences.
Instance Attribute Details
#after_commit_specifier ⇒ String
The branch, tag, HEAD, or other fully qualified reference used to identify a commit.
3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 |
# File 'lib/aws-sdk-codecommit/types.rb', line 3202 class GetDifferencesInput < Struct.new( :repository_name, :before_commit_specifier, :after_commit_specifier, :before_path, :after_path, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#after_path ⇒ String
The file path in which to check differences. Limits the results to this path. Can also be used to specify the changed name of a directory or folder, if it has changed. If not specified, differences are shown for all paths.
3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 |
# File 'lib/aws-sdk-codecommit/types.rb', line 3202 class GetDifferencesInput < Struct.new( :repository_name, :before_commit_specifier, :after_commit_specifier, :before_path, :after_path, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#before_commit_specifier ⇒ String
The branch, tag, HEAD, or other fully qualified reference used to
identify a commit (for example, the full commit ID). Optional. If
not specified, all changes before the afterCommitSpecifier value
are shown. If you do not use beforeCommitSpecifier in your
request, consider limiting the results with maxResults.
3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 |
# File 'lib/aws-sdk-codecommit/types.rb', line 3202 class GetDifferencesInput < Struct.new( :repository_name, :before_commit_specifier, :after_commit_specifier, :before_path, :after_path, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#before_path ⇒ String
The file path in which to check for differences. Limits the results
to this path. Can also be used to specify the previous name of a
directory or folder. If beforePath and afterPath are not
specified, differences are shown for all paths.
3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 |
# File 'lib/aws-sdk-codecommit/types.rb', line 3202 class GetDifferencesInput < Struct.new( :repository_name, :before_commit_specifier, :after_commit_specifier, :before_path, :after_path, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
A non-zero, non-negative integer used to limit the number of returned results.
3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 |
# File 'lib/aws-sdk-codecommit/types.rb', line 3202 class GetDifferencesInput < Struct.new( :repository_name, :before_commit_specifier, :after_commit_specifier, :before_path, :after_path, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An enumeration token that, when provided in a request, returns the next batch of the results.
3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 |
# File 'lib/aws-sdk-codecommit/types.rb', line 3202 class GetDifferencesInput < Struct.new( :repository_name, :before_commit_specifier, :after_commit_specifier, :before_path, :after_path, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#repository_name ⇒ String
The name of the repository where you want to get differences.
3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 |
# File 'lib/aws-sdk-codecommit/types.rb', line 3202 class GetDifferencesInput < Struct.new( :repository_name, :before_commit_specifier, :after_commit_specifier, :before_path, :after_path, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |