Class: Aws::CodeCommit::Types::MergePullRequestByFastForwardInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeCommit::Types::MergePullRequestByFastForwardInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codecommit/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#pull_request_id ⇒ String
The system-generated ID of the pull request.
-
#repository_name ⇒ String
The name of the repository where the pull request was created.
-
#source_commit_id ⇒ String
The full commit ID of the original or updated commit in the pull request source branch.
Instance Attribute Details
#pull_request_id ⇒ String
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
5115 5116 5117 5118 5119 5120 5121 |
# File 'lib/aws-sdk-codecommit/types.rb', line 5115 class MergePullRequestByFastForwardInput < Struct.new( :pull_request_id, :repository_name, :source_commit_id) SENSITIVE = [] include Aws::Structure end |
#repository_name ⇒ String
The name of the repository where the pull request was created.
5115 5116 5117 5118 5119 5120 5121 |
# File 'lib/aws-sdk-codecommit/types.rb', line 5115 class MergePullRequestByFastForwardInput < Struct.new( :pull_request_id, :repository_name, :source_commit_id) SENSITIVE = [] include Aws::Structure end |
#source_commit_id ⇒ String
The full commit ID of the original or updated commit in the pull request source branch. Pass this value if you want an exception thrown if the current commit ID of the tip of the source branch does not match this commit ID.
5115 5116 5117 5118 5119 5120 5121 |
# File 'lib/aws-sdk-codecommit/types.rb', line 5115 class MergePullRequestByFastForwardInput < Struct.new( :pull_request_id, :repository_name, :source_commit_id) SENSITIVE = [] include Aws::Structure end |