Class: Aws::CodeCommit::Types::PutFileEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeCommit::Types::PutFileEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codecommit/types.rb
Overview
Information about a file added or updated as part of a commit.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#file_content ⇒ String
The content of the file, if a source file is not specified.
-
#file_mode ⇒ String
The extrapolated file mode permissions for the file.
-
#file_path ⇒ String
The full path to the file in the repository, including the name of the file.
-
#source_file ⇒ Types::SourceFileSpecifier
The name and full path of the file that contains the changes you want to make as part of the commit, if you are not providing the file content directly.
Instance Attribute Details
#file_content ⇒ String
The content of the file, if a source file is not specified.
6123 6124 6125 6126 6127 6128 6129 6130 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6123 class PutFileEntry < Struct.new( :file_path, :file_mode, :file_content, :source_file) SENSITIVE = [] include Aws::Structure end |
#file_mode ⇒ String
The extrapolated file mode permissions for the file. Valid values include EXECUTABLE and NORMAL.
6123 6124 6125 6126 6127 6128 6129 6130 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6123 class PutFileEntry < Struct.new( :file_path, :file_mode, :file_content, :source_file) SENSITIVE = [] include Aws::Structure end |
#file_path ⇒ String
The full path to the file in the repository, including the name of the file.
6123 6124 6125 6126 6127 6128 6129 6130 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6123 class PutFileEntry < Struct.new( :file_path, :file_mode, :file_content, :source_file) SENSITIVE = [] include Aws::Structure end |
#source_file ⇒ Types::SourceFileSpecifier
The name and full path of the file that contains the changes you want to make as part of the commit, if you are not providing the file content directly.
6123 6124 6125 6126 6127 6128 6129 6130 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6123 class PutFileEntry < Struct.new( :file_path, :file_mode, :file_content, :source_file) SENSITIVE = [] include Aws::Structure end |