Class: Aws::CodeCommit::Types::PutFileInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeCommit::Types::PutFileInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codecommit/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#branch_name ⇒ String
The name of the branch where you want to add or update the file.
-
#commit_message ⇒ String
A message about why this file was added or updated.
-
#email ⇒ String
An email address for the person adding or updating the file.
-
#file_content ⇒ String
The content of the file, in binary object format.
-
#file_mode ⇒ String
The file mode permissions of the blob.
-
#file_path ⇒ String
The name of the file you want to add or update, including the relative path to the file in the repository.
-
#name ⇒ String
The name of the person adding or updating the file.
-
#parent_commit_id ⇒ String
The full commit ID of the head commit in the branch where you want to add or update the file.
-
#repository_name ⇒ String
The name of the repository where you want to add or update the file.
Instance Attribute Details
#branch_name ⇒ String
The name of the branch where you want to add or update the file. If this is an empty repository, this branch is created.
6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6196 class PutFileInput < Struct.new( :repository_name, :branch_name, :file_content, :file_path, :file_mode, :parent_commit_id, :commit_message, :name, :email) SENSITIVE = [] include Aws::Structure end |
#commit_message ⇒ String
A message about why this file was added or updated. Although it is optional, a message makes the commit history for your repository more useful.
6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6196 class PutFileInput < Struct.new( :repository_name, :branch_name, :file_content, :file_path, :file_mode, :parent_commit_id, :commit_message, :name, :email) SENSITIVE = [] include Aws::Structure end |
#email ⇒ String
An email address for the person adding or updating the file.
6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6196 class PutFileInput < Struct.new( :repository_name, :branch_name, :file_content, :file_path, :file_mode, :parent_commit_id, :commit_message, :name, :email) SENSITIVE = [] include Aws::Structure end |
#file_content ⇒ String
The content of the file, in binary object format.
6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6196 class PutFileInput < Struct.new( :repository_name, :branch_name, :file_content, :file_path, :file_mode, :parent_commit_id, :commit_message, :name, :email) SENSITIVE = [] include Aws::Structure end |
#file_mode ⇒ String
The file mode permissions of the blob. Valid file mode permissions are listed here.
6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6196 class PutFileInput < Struct.new( :repository_name, :branch_name, :file_content, :file_path, :file_mode, :parent_commit_id, :commit_message, :name, :email) SENSITIVE = [] include Aws::Structure end |
#file_path ⇒ String
The name of the file you want to add or update, including the relative path to the file in the repository.
6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6196 class PutFileInput < Struct.new( :repository_name, :branch_name, :file_content, :file_path, :file_mode, :parent_commit_id, :commit_message, :name, :email) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the person adding or updating the file. Although it is optional, a name makes the commit history for your repository more useful.
6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6196 class PutFileInput < Struct.new( :repository_name, :branch_name, :file_content, :file_path, :file_mode, :parent_commit_id, :commit_message, :name, :email) SENSITIVE = [] include Aws::Structure end |
#parent_commit_id ⇒ String
The full commit ID of the head commit in the branch where you want to add or update the file. If this is an empty repository, no commit ID is required. If this is not an empty repository, a commit ID is required.
The commit ID must match the ID of the head commit at the time of the operation. Otherwise, an error occurs, and the file is not added or updated.
6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6196 class PutFileInput < Struct.new( :repository_name, :branch_name, :file_content, :file_path, :file_mode, :parent_commit_id, :commit_message, :name, :email) SENSITIVE = [] include Aws::Structure end |
#repository_name ⇒ String
The name of the repository where you want to add or update the file.
6196 6197 6198 6199 6200 6201 6202 6203 6204 6205 6206 6207 6208 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6196 class PutFileInput < Struct.new( :repository_name, :branch_name, :file_content, :file_path, :file_mode, :parent_commit_id, :commit_message, :name, :email) SENSITIVE = [] include Aws::Structure end |