Method: Aws::CodeCommit::Types::RepositoryTrigger#custom_data
- Defined in:
- lib/aws-sdk-codecommit/types.rb
#custom_data ⇒ String
Any custom data associated with the trigger to be included in the information sent to the target of the trigger.
6390 6391 6392 6393 6394 6395 6396 6397 6398 |
# File 'lib/aws-sdk-codecommit/types.rb', line 6390 class RepositoryTrigger < Struct.new( :name, :destination_arn, :custom_data, :branches, :events) SENSITIVE = [] include Aws::Structure end |